<?php
namespace SF\Sfcombination\Domain\Model;


/***************************************************************
 *
 *  Copyright notice
 *
 *  (c) 2014 Stefan Frömken <froemken@gmail.com>
 *
 *  All rights reserved
 *
 *  This script is part of the TYPO3 project. The TYPO3 project is
 *  free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  The GNU General Public License can be found at
 *  http://www.gnu.org/copyleft/gpl.html.
 *
 *  This script is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  This copyright notice MUST APPEAR in all copies of the script!
 ***************************************************************/

/**
 * Cars
 */
class Car extends \TYPO3\CMS\Extbase\DomainObject\AbstractEntity {

	/**
	 * Brand
	 *
	 * @var string
	 * @validate NotEmpty
	 */
	protected $brand = '';

	/**
	 * Features
	 *
	 * @var \TYPO3\CMS\Extbase\Persistence\ObjectStorage<\SF\Sfcombination\Domain\Model\CarFeatureMm>
	 * @cascade remove
	 */
	protected $features;

	/**
	 * __construct
	 */
	public function __construct() {
		//Do not remove the next line: It would break the functionality
		$this->initStorageObjects();
	}

	/**
	 * Initializes all ObjectStorage properties
	 * Do not modify this method!
	 * It will be rewritten on each save in the extension builder
	 * You may modify the constructor of this class instead
	 *
	 * @return void
	 */
	protected function initStorageObjects() {
		$this->features = new \TYPO3\CMS\Extbase\Persistence\ObjectStorage();
	}

	/**
	 * Returns the brand
	 *
	 * @return string $brand
	 */
	public function getBrand() {
		return $this->brand;
	}

	/**
	 * Sets the brand
	 *
	 * @param string $brand
	 * @return void
	 */
	public function setBrand($brand) {
		$this->brand = $brand;
	}

	/**
	 * Adds a CarFeatureMm
	 *
	 * @param \SF\Sfcombination\Domain\Model\CarFeatureMm $feature
	 * @return void
	 */
	public function addFeature(\SF\Sfcombination\Domain\Model\CarFeatureMm $feature) {
		$this->features->attach($feature);
	}

	/**
	 * Removes a CarFeatureMm
	 *
	 * @param \SF\Sfcombination\Domain\Model\CarFeatureMm $featureToRemove The CarFeatureMm to be removed
	 * @return void
	 */
	public function removeFeature(\SF\Sfcombination\Domain\Model\CarFeatureMm $featureToRemove) {
		$this->features->detach($featureToRemove);
	}

	/**
	 * Returns the features
	 *
	 * @return \TYPO3\CMS\Extbase\Persistence\ObjectStorage<\SF\Sfcombination\Domain\Model\CarFeatureMm> $features
	 */
	public function getFeatures() {
		return $this->features;
	}

	/**
	 * Sets the features
	 *
	 * @param \TYPO3\CMS\Extbase\Persistence\ObjectStorage<\SF\Sfcombination\Domain\Model\CarFeatureMm> $features
	 * @return void
	 */
	public function setFeatures(\TYPO3\CMS\Extbase\Persistence\ObjectStorage $features) {
		$this->features = $features;
	}

}