<?php

namespace \Tests\Unit\Domain\Model;

/***************************************************************
 *  Copyright notice
 *
 *  (c) 2014 Stefan Frömken <froemken@gmail.com>
 *
 *  All rights reserved
 *
 *  This script is part of the TYPO3 project. The TYPO3 project is
 *  free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  The GNU General Public License can be found at
 *  http://www.gnu.org/copyleft/gpl.html.
 *
 *  This script is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  This copyright notice MUST APPEAR in all copies of the script!
 ***************************************************************/

/**
 * Test case for class \SF\Sfcombination\Domain\Model\Feature.
 *
 * @version $Id$
 * @copyright Copyright belongs to the respective authors
 * @license http://www.gnu.org/licenses/gpl.html GNU General Public License, version 3 or later
 *
 * @author Stefan Frömken <froemken@gmail.com>
 */
class FeatureTest extends \TYPO3\CMS\Extbase\Tests\Unit\BaseTestCase {
	/**
	 * @var \SF\Sfcombination\Domain\Model\Feature
	 */
	protected $subject;

	public function setUp() {
		$this->subject = new \SF\Sfcombination\Domain\Model\Feature();
	}

	public function tearDown() {
		unset($this->subject);
	}

	/**
	 * @test
	 */
	public function getFeatureReturnsInitialValueForString() {
		$this->assertSame(
			'',
			$this->subject->getFeature()
		);
	}

	/**
	 * @test
	 */
	public function setFeatureForStringSetsFeature() {
		$this->subject->setFeature('Conceived at T3CON10');

		$this->assertAttributeEquals(
			'Conceived at T3CON10',
			'feature',
			$this->subject
		);
	}

	/**
	 * @test
	 */
	public function getCarsReturnsInitialValueForCarFeatureMm() {
		$newObjectStorage = new \TYPO3\CMS\Extbase\Persistence\ObjectStorage();
		$this->assertEquals(
			$newObjectStorage,
			$this->subject->getCars()
		);
	}

	/**
	 * @test
	 */
	public function setCarsForObjectStorageContainingCarFeatureMmSetsCars() {
		$car = new \SF\Sfcombination\Domain\Model\CarFeatureMm();
		$objectStorageHoldingExactlyOneCars = new \TYPO3\CMS\Extbase\Persistence\ObjectStorage();
		$objectStorageHoldingExactlyOneCars->attach($car);
		$this->subject->setCars($objectStorageHoldingExactlyOneCars);

		$this->assertAttributeEquals(
			$objectStorageHoldingExactlyOneCars,
			'cars',
			$this->subject
		);
	}

	/**
	 * @test
	 */
	public function addCarToObjectStorageHoldingCars() {
		$car = new \SF\Sfcombination\Domain\Model\CarFeatureMm();
		$carsObjectStorageMock = $this->getMock('TYPO3\\CMS\\Extbase\\Persistence\\ObjectStorage', array('attach'), array(), '', FALSE);
		$carsObjectStorageMock->expects($this->once())->method('attach')->with($this->equalTo($car));
		$this->inject($this->subject, 'cars', $carsObjectStorageMock);

		$this->subject->addCar($car);
	}

	/**
	 * @test
	 */
	public function removeCarFromObjectStorageHoldingCars() {
		$car = new \SF\Sfcombination\Domain\Model\CarFeatureMm();
		$carsObjectStorageMock = $this->getMock('TYPO3\\CMS\\Extbase\\Persistence\\ObjectStorage', array('detach'), array(), '', FALSE);
		$carsObjectStorageMock->expects($this->once())->method('detach')->with($this->equalTo($car));
		$this->inject($this->subject, 'cars', $carsObjectStorageMock);

		$this->subject->removeCar($car);

	}
}
